menu
custom_sizable_text package
documentation
custom_sizable_text.dart
custom_sizable_text.dart
dark_mode
light_mode
custom_sizable_text
library
Classes
CustomText
CustomText
is a widget that simplifies the text widget and make it flexible and auto sized.
Enums
TextType
TextType
is an enum that allows you to make text not sizable by change
textType
custom_sizable_text package
documentation
custom_sizable_text.dart
custom_sizable_text
package
Libraries
custom_sizable_text
custom_sizable_text library